Thank you for contributing to this project! Before you submit a Pull Request:

* Be sure to read the [contribution guidelines](https://github.com/gidden/ptolemy/blob/latest/docs/CONTRIBUTING.rst)
* refer to the [issue](https://github.com/gidden/ptolemy/issues) that describes the problem you want to address/solve or,
* if no issue exists, directly describe the problem in your pull request
* summarize the approach used to address the issue